﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Telerik.Windows.Controls;
using Telerik.Windows;
using System.Windows.Data;
using System.ComponentModel;

namespace DropDownWithGrid_SL
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }
    }

    public class DropDownButtonExtensions
    {
        public static bool GetCloseDropDownOnSelectionChanged(DependencyObject obj)
        {
            return (bool)obj.GetValue(CloseDropDownOnSelectionChangedProperty);
        }

        public static void SetCloseDropDownOnSelectionChanged(DependencyObject obj, bool value)
        {
            obj.SetValue(CloseDropDownOnSelectionChangedProperty, value);
        }

        public static readonly DependencyProperty CloseDropDownOnSelectionChangedProperty =
            DependencyProperty.RegisterAttached("CloseDropDownOnSelectionChanged", typeof(bool), typeof(DropDownButtonExtensions), new System.Windows.PropertyMetadata(OnCloseDropDownOnSelectionChangedChanged));

        private static void OnCloseDropDownOnSelectionChangedChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var dropDownButton = d as RadDropDownButton;

            RoutedEventHandler dropDownButtonLoaded = null;
            dropDownButtonLoaded = (ss, ee) =>
                {
                    var gridView = dropDownButton.DropDownContent as RadGridView;
                    RoutedEventHandler gridViewLoaded = null;
                    gridViewLoaded = new RoutedEventHandler((s, ev) =>
                        {
                            dropDownButton.AddHandler(RadGridView.SelectionChangedEvent, new EventHandler<SelectionChangeEventArgs>((sender, args) =>
                            {
                                (sender as RadDropDownButton).IsOpen = false;
                            }));
                            gridView.Loaded -= gridViewLoaded;
                        });

                    gridView.Loaded += gridViewLoaded;
                    dropDownButton.Loaded -= dropDownButtonLoaded;
                };
            dropDownButton.Loaded += dropDownButtonLoaded;
        }
    }

    public class CustomerConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            var customers = parameter as CustomerCollection;

            var id = (int)value;

            var customer = customers.FirstOrDefault((c) => c.CustomerID == id);

            return customer;
        }

        public object  ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            var customer = value as Customer;

            if (customer == null )
            {
                return null;
            }
            else
            {
                return customer.CustomerID;
            }
        }
    }

    public class CustomerCollection : ObservableCollection<Customer>
    {
        public CustomerCollection()
        {
            this.Add(new Customer() { FirstName = "John", LastName = "Smith", CustomerID=1 });
            this.Add(new Customer() { FirstName = "Jane", LastName = "Smith", CustomerID=2 });
            this.Add(new Customer() { FirstName = "Josh", LastName = "Smith", CustomerID=3 });
        }
    }

    public class OrderCollection : ObservableCollection<Order>
    {
        public OrderCollection()
        {
            this.Add(new Order() { Date = DateTime.Now, ProductName = "Car", CustomerID = 2 });
            this.Add(new Order() { Date = DateTime.Now, ProductName = "Motorcycle", CustomerID = 1 });
            this.Add(new Order() { Date = DateTime.Now, ProductName = "Truck", CustomerID = 3 });
        }
    }

    public class Customer : INotifyPropertyChanged
    {
        private int customerID;
        private string firstName;
        private string lastName;

        public int CustomerID
        {
            get
            {
                return this.customerID;
            }
            set
            {
                if (this.customerID != value)
                {
                    this.customerID = value;
                    this.OnPropertyChanged("CustomerID");
                }
            }
        }

        public string FirstName
        {
            get
            {
                return this.firstName;
            }
            set
            {
                if (this.firstName != value)
                {
                    this.firstName = value;
                    this.OnPropertyChanged("FirstName");
                }
            }
        }

        public string LastName
        {
            get
            {
                return this.lastName;
            }
            set
            {
                if (this.lastName != value)
                {
                    this.lastName = value;
                    this.OnPropertyChanged("LastName");
                }
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }

    public class Order : INotifyPropertyChanged
    {
        private int customerID;

        public int CustomerID
        {
            get
            {
                return this.customerID;
            }
            set
            {
                if (this.customerID != value)
                {
                    this.customerID = value;
                    this.OnPropertyChanged("CustomerID");
                }
            }
        }

        public DateTime Date { get; set; }
        public string ProductName { get; set; }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}